@@ -414,7 +414,8 @@ class KojiModuleBuilder(GenericBuilder):
         if len(nsvc_tag) + len("-build") > max_length:
             # Fallback to the old format of 'module-<hash>' if the generated koji tag
             # name is longer than max_length
-            nsvc_hash = hashlib.sha1(".".join(nsvc_list).encode("utf-8")).hexdigest()[:16]
+            nsvc_hash = hashlib.sha1(".".join(nsvc_list).encode("utf-8"),
+                                     usedforsecurity=False).hexdigest()[:16]
             return prefix + nsvc_hash + suffix
         return nsvc_tag
 
