@@ -21,6 +21,10 @@ class UnprocessableEntity(ValueError):
     pass
 
 
+class StreamNotXyz(UnprocessableEntity):
+    pass
+
+
 class Conflict(ValueError):
     pass
 
@@ -37,9 +41,5 @@ class StreamAmbigous(ValueError):
     pass
 
 
-class GreenwaveError(RuntimeError):
-    pass
-
-
 class IgnoreMessage(Exception):
     """Raise if message received from message bus should be ignored"""
