@@ -58,6 +58,6 @@ def downgrade():
         if build.build_context and build.runtime_context:
             combined_hashes = '{0}:{1}'.format(
                 build.build_context, build.runtime_context).encode('utf-8')
-            context = hashlib.sha1(combined_hashes).hexdigest()[:8]
+            context = hashlib.sha1(combined_hashes, usedforsecurity=False).hexdigest()[:8]
             connection.execute(
                 modulebuild.update().where(modulebuild.c.id == build.id).values(context=context))
