@@ -6,7 +6,7 @@ import sqlalchemy
 from sqlalchemy.orm import aliased
 
 from module_build_service.common import log, models
-from module_build_service.common.errors import UnprocessableEntity
+from module_build_service.common.errors import StreamNotXyz, UnprocessableEntity
 from module_build_service.common.utils import load_mmd
 from module_build_service.resolver.base import GenericResolver
 
@@ -23,11 +23,10 @@ class DBResolver(GenericResolver):
         self.config = config
 
     def get_module(
-        self, name, stream, version, context,
-        state=models.BUILD_STATES["ready"], strict=False
+        self, name, stream, version, context, strict=False
     ):
         mb = models.ModuleBuild.get_build_from_nsvc(
-            self.db_session, name, stream, version, context, state=state)
+            self.db_session, name, stream, version, context, state=models.BUILD_STATES["ready"])
         if mb:
             return mb.extended_json(self.db_session)
 
@@ -111,26 +110,31 @@ class DBResolver(GenericResolver):
         :param stream_version_lte: If True, the compatible streams are limited
              by the stream version computed from `stream`. If False, even the
              modules with higher stream version are returned.
-        :param virtual_streams: List of virtual streams. If set, also modules
-            with incompatible stream version are returned in case they share
-            one of the virtual streams.
+        :param virtual_streams: List of virtual streams.
+            Modules are returned if they share one of the virtual streams.
         :param states: List of states the returned compatible modules should
             be in.
         :return list: List of Modulemd objects.
         """
+        if not virtual_streams:
+            raise RuntimeError("Virtual stream list must not be empty")
+
         name = base_module_mmd.get_module_name()
         stream = base_module_mmd.get_stream_name()
         builds = []
+
         stream_version = None
         if stream_version_lte:
             stream_in_xyz_format = len(str(models.ModuleBuild.get_stream_version(
                 stream, right_pad=False))) >= 5
-            if stream_in_xyz_format:
-                stream_version = models.ModuleBuild.get_stream_version(stream)
-            else:
-                log.warning(
-                    "Cannot get compatible base modules, because stream_version_lte is used, "
-                    "but stream %r is not in x.y.z format." % stream)
+            if not stream_in_xyz_format:
+                raise StreamNotXyz(
+                    "Cannot get compatible base modules, because stream of resolved "
+                    "base module %s:%s is not in x.y.z format." % (
+                        base_module_mmd.get_module_name(), stream
+                    ))
+            stream_version = models.ModuleBuild.get_stream_version(stream)
+
         builds = models.ModuleBuild.get_last_builds_in_stream_version_lte(
             self.db_session, name, stream_version, virtual_streams, states)
 
@@ -280,6 +284,7 @@ class DBResolver(GenericResolver):
                     ", ".join([name, stream, str(version), context]), strict)
             )
 
+        module_build = None
         module_tags = {}
         if mmd:
             queried_mmd = mmd
@@ -290,14 +295,14 @@ class DBResolver(GenericResolver):
                 mmd.get_context() or models.DEFAULT_MODULE_CONTEXT,
             ])
         else:
-            build = models.ModuleBuild.get_build_from_nsvc(
+            module_build = models.ModuleBuild.get_build_from_nsvc(
                 self.db_session, name, stream, version, context)
-            if not build:
+            if not module_build:
                 raise UnprocessableEntity(
                     "The module {} was not found".format(
                         ":".join([name, stream, version, context]))
                 )
-            queried_mmd = build.mmd()
+            queried_mmd = module_build.mmd()
             nsvc = ":".join([name, stream, version, context])
 
         xmd_mbs = queried_mmd.get_xmd().get("mbs", {})
@@ -309,6 +314,7 @@ class DBResolver(GenericResolver):
 
         buildrequires = xmd_mbs["buildrequires"]
         side_tag = xmd_mbs.get("side_tag")
+        side_tag_brs_found = []
         for br_name, details in buildrequires.items():
             build = models.ModuleBuild.get_build_from_nsvc(
                 self.db_session,
@@ -328,6 +334,7 @@ class DBResolver(GenericResolver):
                 side_tag_format = build.mmd().get_xmd().get("mbs", {}).get("koji_side_tag_format")
                 if side_tag_format:
                     koji_tag = side_tag_format.format(side_tag=side_tag)
+                    side_tag_brs_found.append(side_tag_format)
                     log.info("Using side tag for base module %s: %s", br_name, koji_tag)
                 else:
                     log.warning("Side tag requested, but base module %s lacks koji_side_tag_format"
@@ -340,6 +347,11 @@ class DBResolver(GenericResolver):
             module_tags.setdefault(koji_tag, [])
             module_tags[koji_tag].append(build.mmd())
 
+        if side_tag and not side_tag_brs_found:
+            msg = "None of the buildrequired base modules are configured for side tags."
+            if module_build:
+                module_build.log_message(self.db_session, msg)
+            raise RuntimeError(msg)
         return module_tags
 
     def resolve_requires(self, requires):
