@@ -9,6 +9,7 @@ import tempfile
 import dnf
 import kobo.rpmlib
 import koji
+import packaging.version
 import six.moves.xmlrpc_client as xmlrpclib
 
 from module_build_service.common import conf, log, models, scm
@@ -216,7 +217,7 @@ def _get_rawhide_version():
         return build_target["build_tag_name"].partition("-build")[0]
 
 
-def handle_collisions_with_base_module_rpms(mmd, arches):
+def handle_collisions_with_base_module_rpms(mmd, arches, force_for_old_dnf=False):
     """
     Find any RPMs in the buildrequired base modules that collide with the buildrequired modules.
 
@@ -226,8 +227,22 @@ def handle_collisions_with_base_module_rpms(mmd, arches):
 
     :param Modulemd.ModuleStream mmd: the modulemd to find the collisions
     :param list arches: the arches to limit the external repo queries to
+    :param bool force_for_old_dnf: add the conflicts even if libdnf can't handle them
     :raise RuntimeError: when a Koji query fails
     """
+    if (not force_for_old_dnf
+            and packaging.version.parse(dnf.VERSION) < packaging.version.parse('4.2.19')):
+        # For local builds, we can't use this code unless libdnf uses libmodulemd2
+        # (done in libdnf-0.45) - we can't check the libdnf version, so use
+        # dnf-4.2.19 (which requires libdnf-0.45) as a proxy.
+        log.warning(
+            "The necessary conflicts could not be generated due to RHBZ#1693683. "
+            "Some RPMs from the base modules (%s) may end up being used over modular RPMs. "
+            "This may result in different behavior than a production build.",
+            ", ".join(conf.base_module_names)
+        )
+        return
+
     log.info("Finding any buildrequired modules that collide with the RPMs in the base modules")
     bm_tags = set()
     non_bm_tags = set()
