@@ -2,6 +2,7 @@
 # SPDX-License-Identifier: MIT
 from __future__ import absolute_import
 from datetime import timedelta, datetime
+import time
 import operator
 
 import koji
@@ -20,7 +21,6 @@ from module_build_service.scheduler.batches import (
     start_next_batch_build,
 )
 from module_build_service.scheduler.db_session import db_session
-from module_build_service.scheduler.greenwave import greenwave
 from module_build_service.scheduler.handlers.components import build_task_finalize
 from module_build_service.scheduler.handlers.tags import tagged
 
@@ -36,7 +36,6 @@ def setup_periodic_tasks(sender, **kwargs):
         (cleanup_stale_failed_builds, "Cleanup stale failed builds"),
         (cancel_stuck_module_builds, "Cancel stuck module builds"),
         (sync_koji_build_tags, "Sync Koji build tags"),
-        (poll_greenwave, "Gating module build to ready state"),
     )
 
     for task, name in tasks:
@@ -105,6 +104,7 @@ def fail_lost_builds():
     # TODO re-use
 
     if conf.system == "koji":
+        ten_minutes = timedelta(minutes=10)
         # We don't do this on behalf of users
         koji_session = get_session(conf, login=False)
         log.info("Querying tasks for statuses:")
@@ -119,15 +119,17 @@ def fail_lost_builds():
             if not component_build.task_id:
                 continue
 
-            # Don't check tasks for components which have been reused,
-            # they may have BUILDING state temporarily before we tag them
-            # to new module tag. Checking them would be waste of resources.
+            # For components which have been reused, wait 10 minutes before checking.
+            # They may be in BUILDING state temporarily before we tag them
+            # to new module tag. Checking them at that point would be waste of resources.
             if component_build.reused_component_id:
-                log.debug(
-                    'Skipping check for task "%s", the component has been reused ("%s").',
-                    component_build.task_id, component_build.reused_component_id
-                )
-                continue
+                now = datetime.utcnow()
+                if (now - component_build.module_build.time_modified) < ten_minutes:
+                    log.debug(
+                        'Skipping check for task "%s", the component has been reused ("%s").',
+                        component_build.task_id, component_build.reused_component_id
+                    )
+                    continue
 
             task_id = component_build.task_id
 
@@ -165,6 +167,7 @@ def fail_lost_builds():
                     build_name=component_build.package,
                     build_release=build_release,
                     build_version=build_version,
+                    module_build_id=component_build.module_build.id,
                 )
 
     elif conf.system == "mock":
@@ -402,7 +405,7 @@ def sync_koji_build_tags():
         models.ModuleBuild.state == models.BUILD_STATES["build"]
     ).all()
     for module_build in module_builds:
-        complete_components = module_build.current_batch(koji.BUILD_STATES["COMPLETE"])
+        complete_components = module_build.up_to_current_batch(state=koji.BUILD_STATES["COMPLETE"])
         for c in complete_components:
             # In case the component is tagged in the build tag and
             # also tagged in the final tag (or it is build_time_only
@@ -438,32 +441,6 @@ def sync_koji_build_tags():
                 tagged.delay("internal:sync_koji_build_tags", build_tag, c.nvr)
 
 
-@celery_app.task
-def poll_greenwave():
-    """Polls Greenwave for all builds in done state"""
-    if greenwave is None:
-        return
-
-    module_builds = db_session.query(models.ModuleBuild).filter_by(
-        state=models.BUILD_STATES["done"],
-        scratch=False
-    ).all()
-
-    log.info("Checking Greenwave for %d builds", len(module_builds))
-
-    for build in module_builds:
-        if greenwave.check_gating(build):
-            build.transition(db_session, conf, state=models.BUILD_STATES["ready"])
-        else:
-            build.state_reason = "Gating failed (MBS will retry in {0} seconds)".format(
-                conf.polling_interval
-            )
-            if greenwave.error_occurred:
-                build.state_reason += " (Error occured while querying Greenwave)"
-            build.time_modified = datetime.utcnow()
-        db_session.commit()
-
-
 def has_missed_new_repo_message(module_build, koji_session):
     """
     Returns whether or not a new repo message has probably been missed.
@@ -476,5 +453,8 @@ def has_missed_new_repo_message(module_build, koji_session):
         'Checking status of newRepo task "%d" for %s',
         module_build.new_repo_task_id, module_build)
     task_info = koji_session.getTaskInfo(module_build.new_repo_task_id)
+    # To avoid a race condition, wait at least 10 minutes to nudge build
+    if task_info['completion_ts'] and (time.time() - task_info['completion_ts']) < 600:
+        return False
     # Other final states, FAILED and CANCELED, are handled by retrigger_new_repo_on_failure
     return task_info["state"] == koji.TASK_STATES["CLOSED"]
