@@ -83,7 +83,9 @@ def get_reusable_module(module):
     #
     # 1) The `conf.allow_only_compatible_base_modules` is False. This means that MBS should
     #    not try to find any compatible base modules in its DB and simply use the buildrequired
-    #    base module as it is.
+    #    base module as it is. (*NOTE* This is different than the meaning of
+    #    allow_only_compatible_base_modules=False when looking up build requirements - where
+    #    it means to accept any module buildrequiring a base modul sharing a virtual stream.)
     # 2) The `conf.allow_only_compatible_base_modules` is True and DBResolver is used. This means
     #    that MBS should try to find the compatible modules using its database.
     #    The `get_base_module_mmds` finds out the list of compatible modules and returns mmds of
@@ -438,7 +440,7 @@ def get_reusable_component(
     # check that arches have not changed
     pkg = mmd.get_rpm_component(component_name)
     if set(pkg.get_arches()) != set(old_mmd.get_rpm_component(component_name).get_arches()):
-        message = ("Cannot reuse the component because its architectures"
+        message = ("Cannot reuse the component {0} because its architectures"
                    " have changed since the compatible module build").format(component_name)
         new_module_build_component.log_message(db_session, message)
         return None
