@@ -5,6 +5,7 @@ from datetime import datetime
 import json
 from multiprocessing.dummy import Pool as ThreadPool
 import os
+from collections import namedtuple
 
 import kobo.rpmlib
 
@@ -17,6 +18,14 @@ from module_build_service.common.utils import to_text_type
 from module_build_service.scheduler.db_session import db_session
 
 
+# The namedtuple to store data passed to _scm_get_latest with following keys:
+#   - rpm_component - The Modulemd.ComponentRPM instance representing
+#                     the component.
+#   - ref_override - The str instance used to override the component's ref
+#                    or None.
+SCMGetLatestData = namedtuple("SCMGetLatestData", "rpm_component ref_override")
+
+
 def get_build_arches(mmd, config):
     """
     Returns the list of architectures for which the module `mmd` should be built.
@@ -123,7 +132,9 @@ def _check_buildopts_arches(mmd, arches):
         return arches
     # Must be a subset of the input module arches
     unsupported_arches = set(buildopts_arches) - set(arches)
-    if unsupported_arches:
+    # If there are unsupported architectures, and the local one is one of them,
+    # then we should fail, otherwise continue.
+    if unsupported_arches and set(arches) in unsupported_arches:
         raise ValidationError("The following buildopts arches are not supported with these "
                               "buildrequires: %r" % unsupported_arches)
     if buildopts_arches:
@@ -205,24 +216,35 @@ def record_filtered_rpms(mmd):
     return mmd
 
 
-def _scm_get_latest(pkg):
+def _scm_get_latest(data):
+    """
+    Resolves the git ref for the package defined in the `data`. Applies git
+    ref override if set in the `data`. Returns a dict with resolved git ref
+    or possible resolving error.
+
+    :param SCMGetLatestData data: Information about the packages to resolve.
+    :return: Dict with following keys:
+        - pkg_name - Name of the resolved package.
+        - pkg_ref - Resolve git ref.
+        - error - Contains the error if any or it is set to `None`.
+    """
     try:
         # If the modulemd specifies that the 'f25' branch is what
         # we want to pull from, we need to resolve that f25 branch
         # to the specific commit available at the time of
         # submission (now).
-        repo = pkg.get_repository()
-        ref = pkg.get_ref()
+        repo = data.rpm_component.get_repository()
+        ref = data.ref_override or data.rpm_component.get_ref()
         log.debug("Getting the commit hash for the ref %s on the repo %s", ref, repo)
         pkgref = module_build_service.common.scm.SCM(repo).get_latest(ref)
     except Exception as e:
         log.exception(e)
         return {
             "error": "Failed to get the latest commit for %s#%s"
-            % (pkg.get_repository(), pkg.get_ref())
+            % (data.rpm_component.get_repository(), data.rpm_component.get_ref())
         }
 
-    return {"pkg_name": pkg.get_name(), "pkg_ref": pkgref, "error": None}
+    return {"pkg_name": data.rpm_component.get_name(), "pkg_ref": pkgref, "error": None}
 
 
 def format_mmd(mmd, scmurl, module=None, db_session=None, srpm_overrides=None):
@@ -287,7 +309,7 @@ def format_mmd(mmd, scmurl, module=None, db_session=None, srpm_overrides=None):
             if not pkg.get_cache():
                 pkg.set_cache(conf.rpms_default_cache + pkgname)
             if not pkg.get_ref():
-                pkg.set_ref("master")
+                pkg.set_ref(conf.default_branch)
             if not pkg.get_arches():
                 for arch in conf.arches:
                     pkg.add_restricted_arch(arch)
@@ -303,7 +325,11 @@ def format_mmd(mmd, scmurl, module=None, db_session=None, srpm_overrides=None):
             if not mod.get_repository():
                 mod.set_repository(conf.modules_default_repository + modname)
             if not mod.get_ref():
-                mod.set_ref("master")
+                mod.set_ref(conf.default_branch)
+
+        # It is possible to override the ref of RPM component using
+        # the rpm_component_ref_overrides.
+        ref_overrides = xmd["mbs"].get("rpm_component_ref_overrides", {})
 
         # Check that SCM URL is valid and replace potential branches in pkg refs
         # by real SCM hash and store the result to our private xmd place in modulemd.
@@ -312,7 +338,7 @@ def format_mmd(mmd, scmurl, module=None, db_session=None, srpm_overrides=None):
             # Filter out the packages which we have already resolved in possible
             # previous runs of this method (can be caused by module build resubmition)
             # or which have custom SRPMs and shouldn't be resolved.
-            pkgs_to_resolve = []
+            scm_get_latest_data_list = []
             for name in mmd.get_rpm_component_names():
                 if name not in xmd["mbs"]["rpms"]:
                     if name in srpm_overrides:
@@ -320,9 +346,17 @@ def format_mmd(mmd, scmurl, module=None, db_session=None, srpm_overrides=None):
                         # ref entry so no further verification takes place.
                         xmd["mbs"]["rpms"][name] = {"ref": None}
                     else:
-                        pkgs_to_resolve.append(mmd.get_rpm_component(name))
+                        # Apply possible ref override.
+                        if name in ref_overrides:
+                            ref_override = ref_overrides[name]
+                            log.info("Applying rpm_component_ref_overrides - "
+                                     "%s, new ref is %s." % (name, ref_override))
+                        else:
+                            ref_override = None
+                        scm_get_latest_data_list.append(
+                            SCMGetLatestData(mmd.get_rpm_component(name), ref_override))
 
-            async_result = pool.map_async(_scm_get_latest, pkgs_to_resolve)
+            async_result = pool.map_async(_scm_get_latest, scm_get_latest_data_list)
 
             # For modules with lot of components, the _scm_get_latest can take a lot of time.
             # We need to bump time_modified from time to time, otherwise poller could think
