@@ -122,7 +122,7 @@ def submit_module_build_from_yaml(
             '"module_name" parameter'
         )
     module_name = stream_or_packager.get_module_name() or def_name
-    module_stream = stream or stream_or_packager.get_stream_name() or "master"
+    module_stream = stream or stream_or_packager.get_stream_name() or conf.default_branch
     if module_name != stream_or_packager.get_module_name() or \
        module_stream != stream_or_packager.get_stream_name():
         # This is how you set the name and stream in the modulemd
@@ -270,6 +270,23 @@ def _apply_dep_overrides(mmd, params):
             )
 
 
+def _apply_rpm_component_ref_overrides(mmd, params):
+    """
+    If `rpm_component_ref_overrides` is given, note it in the xmd.
+
+    :param Modulemd.ModuleStream mmd: the modulemd to apply the overrides on
+    :param dict params: the API parameters passed in by the user
+    """
+    ref_overrides = params.get("rpm_component_ref_overrides", {})
+    if not ref_overrides:
+        # No changes needed.
+        return
+
+    xmd = mmd.get_xmd()
+    xmd.setdefault("mbs", {})["rpm_component_ref_overrides"] = ref_overrides
+    mmd.set_xmd(xmd)
+
+
 def _apply_side_tag(mmd, params):
     """
     If a side tag identifier is given, note it in the xmd
@@ -410,9 +427,14 @@ def _process_support_streams(db_session, mmd, params):
         """
         Check if the specified scheduled task date has been reached. Returns True if it has.
         """
-        if not conf.product_pages_schedule_task_name:
-            log.debug(config_msg, "product_pages_schedule_task_name")
-            return False
+        names = conf.product_pages_schedule_task_names
+        if not names:
+            # also allow for the older, single-valued option
+            if conf.product_pages_schedule_task_name:
+                names = [conf.product_pages_schedule_task_name]
+            else:
+                log.debug(config_msg, "product_pages_schedule_task_names")
+                return False
 
         schedule_url = "{}/api/v7/releases/{}/schedule-tasks/?fields=name,date_finish".format(
             conf.product_pages_url.rstrip("/"), pp_release)
@@ -430,17 +452,18 @@ def _process_support_streams(db_session, mmd, params):
             )
             return False
 
-        name = conf.product_pages_schedule_task_name.lower().strip()
-        for task in pp_json:
-            if task['name'].lower().strip() == name:
-                task_date = task['date_finish']
-                if datetime.strptime(task_date, "%Y-%m-%d").date() >= datetime.utcnow().date():
-                    log.debug(
-                        "The task date %s hasn't been reached yet. Not adding a stream suffix.",
-                        task_date
-                    )
-                    return False
-                return True
+        for name in names:
+            name = name.lower().strip()
+            for task in pp_json:
+                if task['name'].lower().strip() == name:
+                    task_date = task['date_finish']
+                    if datetime.strptime(task_date, "%Y-%m-%d").date() >= datetime.utcnow().date():
+                        log.debug(
+                            "The task date %s hasn't been reached yet. Not adding a stream suffix.",
+                            task_date
+                        )
+                        return False
+                    return True
         # Schedule task not available; rely on GA date
         return False
 
@@ -595,6 +618,7 @@ def submit_module_build(db_session, username, stream_or_packager, params, module
         validate_mmd(mmd)
         _apply_dep_overrides(mmd, params)
         _apply_side_tag(mmd, params)
+        _apply_rpm_component_ref_overrides(mmd, params)
         _modify_buildtime_streams(db_session, mmd, resolve_base_module_virtual_streams)
         _process_support_streams(db_session, mmd, params)
         mmds += generate_expanded_mmds(db_session, mmd, raise_if_stream_ambigous,
@@ -695,15 +719,28 @@ def submit_module_build(db_session, username, stream_or_packager, params, module
                 reused_module_id=params.get("reuse_components_from"),
                 scratch=params.get("scratch"),
                 srpms=params.get("srpms"),
+                # don't commit now, we do it ourselves below
+                commit=False,
             )
             module.build_context, module.runtime_context, module.context, \
                 module.build_context_no_bms = module.contexts_from_mmd(module.modulemd)
 
-            xmd = mmd.get_xmd()
-            if xmd["mbs"].get("static_context"):
+            if static_context:
+                # if the static_context is True we use the context from defined in the mmd
+                # and discard the computed one.
                 module.context = mmd.get_context()
+            else:
+                # if the context is defined by MSE, we need to add a context_suffix if it exists.
+                module.context += context_suffix
+
+            if not conf.allow_dashes_in_svc:
+                if '-' in module.stream:
+                    raise ValidationError('Dashes not allowed in stream')
+                if '-' in module.version:
+                    raise ValidationError('Dashes not allowed in version')
+                if '-' in module.context:
+                    raise ValidationError('Dashes not allowed in context')
 
-            module.context += context_suffix
             db_session.commit()
 
             notify_on_module_state_change(
@@ -752,27 +789,18 @@ def process_module_context_configuration(stream_or_packager):
             if not stream.is_static_context():
                 stream.set_static_context()
 
-            # we get the dependenices of the stream
-            deps = stream.get_dependencies()
-            # with v3 packager format the output v2 stream will always have
-            # only one set of dependecies. We need to remove the platform
-            # virtual module from runtime dependencies as it is not desired.
-            modules = deps[0].get_runtime_modules()
-            module_streams = [(m, deps[0].get_runtime_streams(m)[0]) for m in modules
-                              if m not in conf.base_module_names]
-            deps[0].clear_runtime_dependencies()
-
-            for module_stream in module_streams:
-                module, stream = module_stream
-                deps[0].add_runtime_stream(module, stream)
-
         return streams, static_context
     else:
         xmd = stream_or_packager.get_xmd()
-        # check if we are handling rebuild of a static context module
+
+        # check if the static format is defined through `static_context` field
+        if stream_or_packager.is_static_context():
+            static_context = True
+            return [stream_or_packager], static_context
+
+        # check if we are handling rebuild of a static context module defined in xmd
         if "mbs" in xmd:
-            # check if it is a static context
-            if "static_context" in xmd["mbs"] or stream_or_packager.is_static_context():
+            if "static_context" in xmd["mbs"]:
                 static_context = True
                 return [stream_or_packager], static_context
 
