@@ -13,6 +13,7 @@ import yaml
 from traceback import extract_stack
 
 import koji
+import flask_sqlalchemy
 from mock import patch
 from six import string_types
 
@@ -132,7 +133,7 @@ def truncate_tables():
     db_session.commit()
 
 
-def clean_database(add_platform_module=True, add_default_arches=True):
+def clean_database(database_uri=None, add_platform_module=True, add_default_arches=True):
     """Initialize the test database
 
     This function is responsible for dropping all the data in the database and
@@ -142,6 +143,19 @@ def clean_database(add_platform_module=True, add_default_arches=True):
     Flask-SQLAlchemy.
     """
 
+    if database_uri is not None:
+        # When starting tests, we switch from the memory backend to a
+        # database in the pytest temporary directory, requiring some
+        # hacks
+        db.session.remove()
+        db.session = None
+
+        # clear any cached engine connections
+        flask_sqlalchemy.get_state(module_build_service.app).connnectors = {}
+
+        module_build_service.app.config['SQLALCHEMY_DATABASE_URI'] = database_uri
+        db.session = db.create_scoped_session()
+
     # Helpful for writing tests if any changes were made using the database
     # session but the test didn't commit or rollback.
     #
@@ -409,7 +423,7 @@ def _populate_data(data_size=10, contexts=False, scratch=False):
     db_session.commit()
 
 
-def scheduler_init_data(tangerine_state=None, scratch=False):
+def scheduler_init_data(tangerine_state=None, scratch=False, module_state="build"):
     """ Creates a testmodule in the building state with all the components in the same batch
     """
     clean_database()
@@ -421,7 +435,7 @@ def scheduler_init_data(tangerine_state=None, scratch=False):
         name="testmodule",
         stream="master",
         version='20170109091357',
-        state=BUILD_STATES["build"],
+        state=BUILD_STATES[module_state],
         scratch=scratch,
         build_context="ac4de1c346dcf09ce77d38cd4e75094ec1c08eb0",
         runtime_context="ac4de1c346dcf09ce77d38cd4e75094ec1c08eb0",
