@@ -10,6 +10,7 @@ from os import path, mkdir
 from os.path import dirname
 import re
 import sched
+import signal
 from random import randint
 from shutil import copyfile
 
@@ -83,6 +84,16 @@ def make_simple_stop_condition():
     return stop_condition
 
 
+def make_trapped_stop_condition(stop_condition):
+    def trapped_stop_condition(message):
+        if events.EventTrap.get_exception():
+            return True
+
+        return stop_condition(message)
+
+    return trapped_stop_condition
+
+
 def main(initial_messages, stop_condition):
     """ Run the consumer until some condition is met.
 
@@ -108,18 +119,42 @@ def main(initial_messages, stop_condition):
 
     consumers = [module_build_service.scheduler.consumer.MBSConsumer]
 
-    # Note that the hub we kick off here cannot send any message.  You
-    # should use fedmsg.publish(...) still for that.
-    moksha.hub.main(
-        # Pass in our config dict
-        options=config,
-        # Only run the specified consumers if any are so specified.
-        consumers=consumers,
-        # Do not run default producers.
-        producers=[],
-        # Tell moksha to quiet its logging.
-        framework=False,
-    )
+    old_run = moksha.hub.reactor.reactor.run
+    old_sigint_handler = signal.getsignal(signal.SIGINT)
+
+    def trap_sigint(self, *args):
+        try:
+            raise KeyboardInterrupt()
+        except KeyboardInterrupt as e:
+            events.EventTrap.set_exception(e)
+
+    def set_signals_and_run(*args, **kwargs):
+        signal.signal(signal.SIGINT, trap_sigint)
+        try:
+            old_run(*args, **kwargs)
+        finally:
+            signal.signal(signal.SIGINT, old_sigint_handler)
+
+    with patch('moksha.hub.reactor.reactor.run', set_signals_and_run):
+        # The events.EventTrap context handler allows us to detect exceptions
+        # in event handlers and re-raise them here so that tests fail usefully
+        # rather than just hang.
+        with events.EventTrap() as trap:
+            # Note that the hub we kick off here cannot send any message.  You
+            # should use fedmsg.publish(...) still for that.
+            moksha.hub.main(
+                # Pass in our config dict
+                options=config,
+                # Only run the specified consumers if any are so specified.
+                consumers=consumers,
+                # Do not run default producers.
+                producers=[],
+                # Tell moksha to quiet its logging.
+                framework=False,
+            )
+
+            if trap.exception:
+                raise trap.exception
 
 
 class FakeSCM(object):
@@ -388,9 +423,10 @@ def cleanup_moksha():
 class BaseTestBuild:
 
     def run_scheduler(self, msgs=None, stop_condition=None):
+        stop_condition = stop_condition or make_simple_stop_condition()
         main(
             msgs or [],
-            stop_condition or make_simple_stop_condition()
+            make_trapped_stop_condition(stop_condition)
         )
 
 
@@ -454,11 +490,6 @@ class TestBuild(BaseTestBuild):
 
         FakeModuleBuilder.on_get_task_info_cb = on_get_task_info_cb
 
-        self.p_check_gating = patch(
-            "module_build_service.scheduler.greenwave.Greenwave.check_gating",
-            return_value=True)
-        self.mock_check_gating = self.p_check_gating.start()
-
         self.patch_config_broker = patch.object(
             module_build_service.common.config.Config,
             "celery_broker_url",
@@ -469,7 +500,6 @@ class TestBuild(BaseTestBuild):
         self.patch_config_broker.start()
 
     def teardown_method(self, test_method):
-        self.p_check_gating.stop()
         self.patch_config_broker.stop()
         FakeModuleBuilder.reset()
         cleanup_moksha()
@@ -628,16 +658,14 @@ class TestBuild(BaseTestBuild):
                 models.BUILD_STATES["ready"],
             ]
 
-    @pytest.mark.parametrize("gating_result", (True, False))
     @patch("module_build_service.web.auth.get_user", return_value=user)
     @patch("module_build_service.common.scm.SCM")
     def test_submit_build_no_components(
-        self, mocked_scm, mocked_get_user, conf_system, dbg, hmsc, gating_result
+        self, mocked_scm, mocked_get_user, conf_system, dbg, hmsc
     ):
         """
         Tests the build of a module with no components
         """
-        self.mock_check_gating.return_value = gating_result
         FakeSCM(
             mocked_scm,
             "python3",
@@ -663,12 +691,6 @@ class TestBuild(BaseTestBuild):
 
         # Make sure no component builds were registered
         assert len(module_build.component_builds) == 0
-        # Make sure the build is done
-        if gating_result:
-            assert module_build.state == models.BUILD_STATES["ready"]
-        else:
-            assert module_build.state == models.BUILD_STATES["done"]
-            assert module_build.state_reason == "Gating failed"
 
     @patch(
         "module_build_service.common.config.Config.check_for_eol",
@@ -1152,16 +1174,24 @@ class TestBuild(BaseTestBuild):
 
         from module_build_service.scheduler.db_session import db_session
 
+        # module should be in wait state for this test
+        module_build = models.ModuleBuild.get_by_id(db_session, 3)
+        module_build.state = models.BUILD_STATES["wait"]
+        db_session.commit()
+
         # Create a dedicated database session for scheduler to avoid hang
         self.run_scheduler(
             msgs=[{
                 "msg_id": "local module build",
                 "event": events.MBS_MODULE_STATE_CHANGE,
-                "module_build_id": 3,
-                "module_build_state": 1
+                "module_build_id": module_build.id,
+                "module_build_state": module_build.state,
             }]
         )
 
+        # commit so that our assertions see the updates
+        db_session.commit()
+
         reused_component_ids = {
             "module-build-macros": None,
             "tangerine": 3,
@@ -1239,6 +1269,11 @@ class TestBuild(BaseTestBuild):
 
         FakeModuleBuilder.on_buildroot_add_artifacts_cb = on_buildroot_add_artifacts_cb
 
+        # module should be in wait state for this test
+        module_build = models.ModuleBuild.get_by_id(db_session, 3)
+        module_build.state = models.BUILD_STATES["wait"]
+        db_session.commit()
+
         self.run_scheduler(
             msgs=[{
                 "msg_id": "local module build",
@@ -1248,6 +1283,9 @@ class TestBuild(BaseTestBuild):
             }]
         )
 
+        # commit so that our assertions see the updates
+        db_session.commit()
+
         # All components should be built and module itself should be in "done"
         # or "ready" state.
         for build in models.ModuleBuild.get_by_id(db_session, 3).component_builds:
@@ -1897,7 +1935,6 @@ class TestLocalBuild(BaseTestBuild):
             except Exception:
                 pass
 
-    @patch("module_build_service.scheduler.greenwave.Greenwave.query_policies")
     @patch("module_build_service.scheduler.handlers.modules.handle_stream_collision_modules")
     @patch("module_build_service.web.auth.get_user", return_value=user)
     @patch("module_build_service.common.scm.SCM")
@@ -1907,7 +1944,7 @@ class TestLocalBuild(BaseTestBuild):
         return_value=staged_data_filename('local_builds'),
     )
     def test_submit_build_local_dependency(
-        self, resultsdir, mocked_scm, mocked_get_user, conf_system, hmsc, mocked_greenwave
+        self, resultsdir, mocked_scm, mocked_get_user, conf_system, hmsc
     ):
         """
         Tests local module build dependency.
