@@ -22,9 +22,6 @@ class TestConfiguration:
     KOJI_REPOSITORY_URL = "https://kojipkgs.stg.fedoraproject.org/repos"
     SCMURLS = ["https://src.stg.fedoraproject.org/modules/"]
     ALLOWED_GROUPS_TO_IMPORT_MODULE = {"mbs-import-module"}
-    GREENWAVE_URL = "https://greenwave.example.local/api/v1.0/"
-    GREENWAVE_DECISION_CONTEXT = "test_dec_context"
-    GREENWAVE_SUBJECT_TYPE = "some-module"
     STREAM_SUFFIXES = {r"^el\d+\.\d+\.\d+\.z$": 0.1}
     CELERY_TASK_ALWAYS_EAGER = True
 
