@@ -90,6 +90,13 @@ def test_add_default_modules_platform_not_available(require_empty_database):
         default_modules.add_default_modules(mmd)
 
 
+# The fedora-style base module versioning here, with f27/f28 sharing the same
+# virtual_stream doesn't work with allow_only_compatible_base_modules, since
+# that expects FOOx.y.z versioning.
+@patch(
+    "module_build_service.common.config.Config.allow_only_compatible_base_modules",
+    new=False
+)
 @patch("module_build_service.scheduler.default_modules._get_default_modules")
 def test_add_default_modules_compatible_platforms(mock_get_dm, require_empty_database):
     """
@@ -291,7 +298,8 @@ def test_handle_collisions_with_base_module_rpms(mock_grft, mock_get_session):
     }
     mock_grft.side_effect = [bm_rpms, non_bm_rpms]
 
-    default_modules.handle_collisions_with_base_module_rpms(mmd, ["aarch64", "x86_64"])
+    default_modules.handle_collisions_with_base_module_rpms(mmd, ["aarch64", "x86_64"],
+                                                            force_for_old_dnf=True)
 
     mock_get_session.assert_called_once()
     xmd_mbs = mmd.get_xmd()["mbs"]
