@@ -2,7 +2,7 @@
 # SPDX-License-Identifier: MIT
 from __future__ import absolute_import
 from datetime import datetime, timedelta
-import re
+import time
 
 import koji
 import mock
@@ -13,7 +13,6 @@ from module_build_service.common.config import conf
 from module_build_service.common import models
 from module_build_service.scheduler import producer
 from module_build_service.scheduler.db_session import db_session
-from tests import make_module_in_db
 
 
 @pytest.mark.usefixtures("reuse_component_init_data")
@@ -79,14 +78,15 @@ class TestPoller:
 
         assert len(start_build_component.mock_calls) == expected_build_calls
 
-    @pytest.mark.parametrize('task_state, expect_start_build_component', (
-        (None, True),  # Indicates a newRepo task has not been triggered yet.
-        (koji.TASK_STATES["CLOSED"], True),
-        (koji.TASK_STATES["OPEN"], False),
+    @pytest.mark.parametrize('completion_ts, task_state, expect_start_build_component', (
+        (None, None, True),  # Indicates a newRepo task has not been triggered yet.
+        ((time.time() - 601), koji.TASK_STATES["CLOSED"], True),
+        (time.time(), koji.TASK_STATES["CLOSED"], False),
+        (None, koji.TASK_STATES["OPEN"], False),
     ))
     @patch("module_build_service.scheduler.batches.start_build_component")
     def test_process_paused_module_builds_with_new_repo_task(
-        self, start_build_component, create_builder, dbg, task_state,
+        self, start_build_component, create_builder, dbg, completion_ts, task_state,
         expect_start_build_component
     ):
         """
@@ -102,7 +102,8 @@ class TestPoller:
         module_build.time_modified = datetime.utcnow() - timedelta(days=5)
         if task_state:
             koji_session = mock.MagicMock()
-            koji_session.getTaskInfo.return_value = {"state": task_state}
+            koji_session.getTaskInfo.return_value = {"state": task_state,
+                                                     "completion_ts": completion_ts}
             builder.koji_session = koji_session
             module_build.new_repo_task_id = 123
         db_session.commit()
@@ -554,44 +555,3 @@ class TestPoller:
 
         tagged_handler.delay.assert_has_calls(
             expected_tagged_calls, any_order=True)
-
-    @pytest.mark.parametrize("greenwave_result", [True, False])
-    @patch("module_build_service.scheduler.greenwave.Greenwave.check_gating")
-    def test_poll_greenwave(self, mock_gw, create_builder, dbg, greenwave_result):
-
-        module_build1 = models.ModuleBuild.get_by_id(db_session, 1)
-        module_build1.state = models.BUILD_STATES["ready"]
-
-        module_build2 = models.ModuleBuild.get_by_id(db_session, 2)
-        module_build2.state = models.BUILD_STATES["done"]
-
-        module_build3 = models.ModuleBuild.get_by_id(db_session, 3)
-        module_build3.state = models.BUILD_STATES["init"]
-
-        module_build4 = make_module_in_db("foo:1:1:1", {})
-        module_build4.state = models.BUILD_STATES["done"]
-        module_build4.scratch = True
-
-        db_session.commit()
-
-        mock_gw.return_value = greenwave_result
-
-        producer.poll_greenwave()
-
-        mock_gw.assert_called_once()
-        modules = models.ModuleBuild.by_state(db_session, "ready")
-
-        if greenwave_result:
-            assert len(modules) == 2
-            assert {m.id for m in modules} == {1, 2}
-        else:
-            assert len(modules) == 1
-            assert modules[0].id == 1
-            modules = models.ModuleBuild.by_state(db_session, "done")
-            assert len(modules) == 2
-            for module in modules:
-                assert module.id in [2, 4]
-                if module.id == 2:
-                    assert re.match("Gating failed.*", module.state_reason)
-                else:
-                    assert module.state_reason is None
